import Config

# Do not include metadata nor timestamps in development logs
config :logger, :console, format: "[$level] $message\n"

# Initialize plugs at runtime for faster development compilation
config :phoenix, :plug_init_mode, :runtime

# Set a higher stacktrace during development. Avoid configuring such
# in production as building large stacktraces may be expensive.
config :phoenix, :stacktrace_depth, 20

config :phoenix_live_view,
  # Include HEEx debug annotations as HTML comments in rendered markup
  debug_heex_annotations: true,
  # Enable helpful, but potentially expensive runtime checks
  enable_expensive_runtime_checks: true

# Disable swoosh api client as it is only required for production adapters.
config :swoosh, :api_client, false

# Configure your database
config :tradex, Tradex.Repo,
  # For development, we disable any cache and enable
  # debugging and code reloading.
  #
  # The watchers configuration can be used to run external
  # watchers to your application. For example, we can use it
  # ## SSL Support
  username: "postgres",
  password: "postgres",
  hostname: "localhost",
  database: "tradex_dev",
  stacktrace: true,
  # to bundle .js and .css sources.
  #
  # In order to use HTTPS in development, a self-signed
  show_sensitive_data_on_connection_error: true,
  pool_size: 10

config :tradex, TradexWeb.Endpoint,
  # Binding to loopback ipv4 address prevents access from other machines.
  # certificate can be generated by running the following

  # Change to `ip: {0, 0, 0, 0}` to allow access from other machines.
  # Mix task:
  #
  #     mix phx.gen.cert
  #
  # Run `mix help phx.gen.cert` for more information.
  #
  # The `http:` config above can be replaced with:
  #
  #     https: [
  #       port: 4001,
  #       cipher_suite: :strong,
  http: [ip: {127, 0, 0, 1}, port: 4000],
  check_origin: false,
  code_reloader: true,
  debug_errors: true,
  secret_key_base: "IMdo6qGMCe4KxTZHusF2cNLuwIoqvRwfM+WgmZIEP+T/fVdg1VSIU1nCPV7ee2SX",
  watchers: [
    esbuild: {Esbuild, :install_and_run, [:tradex, ~w(--sourcemap=inline --watch)]},
    tailwind: {Tailwind, :install_and_run, [:tradex, ~w(--watch)]}
  ]

# Watch static and templates for browser reloading.
#       keyfile: "priv/cert/selfsigned_key.pem",
#       certfile: "priv/cert/selfsigned.pem"
#     ],
#
# If desired, both `http:` and `https:` keys can be
# configured to run both http and https servers on
# different ports.

config :tradex, TradexWeb.Endpoint,
  live_reload: [
    patterns: [
      ~r"priv/static/(?!uploads/).*(js|css|png|jpeg|jpg|gif|svg)$",
      ~r"priv/gettext/.*(po)$",
      ~r"lib/tradex_web/(controllers|live|components)/.*(ex|heex)$"
    ]
  ]

# Enable dev routes for dashboard and mailbox
config :tradex, dev_routes: true
