defmodule TradexWeb.SecurityController do
  use TradexWeb, :controller

  alias Tradex.Instruments
  alias Tradex.Instruments.Security

  def index(conn, _params) do
    securities = Instruments.list_securities()
    render(conn, :index, securities: securities)
  end

  def new(conn, _params) do
    changeset = Instruments.change_security(%Security{})
    render(conn, :new, changeset: changeset)
  end

  def create(conn, %{"security" => security_params}) do
    case Instruments.create_security(security_params) do
      {:ok, security} ->
        conn
        |> put_flash(:info, "Security created successfully.")
        |> redirect(to: ~p"/securities/#{security}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :new, changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}) do
    security = Instruments.get_security!(id)
    render(conn, :show, security: security)
  end

  def edit(conn, %{"id" => id}) do
    security = Instruments.get_security!(id)
    changeset = Instruments.change_security(security)
    render(conn, :edit, security: security, changeset: changeset)
  end

  def update(conn, %{"id" => id, "security" => security_params}) do
    security = Instruments.get_security!(id)

    case Instruments.update_security(security, security_params) do
      {:ok, security} ->
        conn
        |> put_flash(:info, "Security updated successfully.")
        |> redirect(to: ~p"/securities/#{security}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :edit, security: security, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    security = Instruments.get_security!(id)
    {:ok, _security} = Instruments.delete_security(security)

    conn
    |> put_flash(:info, "Security deleted successfully.")
    |> redirect(to: ~p"/securities")
  end
end
